==> qtcreator_4.5.2.orig.tar.xz: qt-creator-opensource-src-4.5.2/src/tools/clangrefactoringbackend/source/clangrefactoringbackend_global.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

namespace llvm {
template <typename T, unsigned N>
class SmallVector;
}

namespace ClangBackEnd {

using USRName = llvm::SmallVector<char, 128>;

// use std::filesystem::path if it is supported by all compilers
#ifdef _WIN32
const char nativeSeperator = '\\';
#else
const char nativeSeperator = '/';
#endif

}

==> qtcreator_4.14.1.orig.tar.xz: qt-creator-opensource-src-4.14.1/src/tools/clangrefactoringbackend/source/clangrefactoringbackend_global.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <utils/hostosinfo.h>

namespace llvm {
template <typename T, unsigned N>
class SmallVector;
}

namespace ClangBackEnd {

using USRName = llvm::SmallVector<char, 128>;

// use std::filesystem::path if it is supported by all compilers

static const char nativeSeparator = Utils::HostOsInfo::isWindowsHost() ? '\\' : '/';

}
